@@ -17,6 +17,7 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
+from .literals import PlaybackModeType
 from .paginator import (
     GetChannelSchedulePaginator,
     ListAlertsPaginator,
@@ -57,6 +58,7 @@ from .type_defs import (
     PutPlaybackConfigurationResponseTypeDef,
     RequestOutputItemTypeDef,
     ScheduleConfigurationTypeDef,
+    SlateSourceTypeDef,
     UpdateChannelResponseTypeDef,
     UpdateSourceLocationResponseTypeDef,
     UpdateVodSourceResponseTypeDef,
@@ -86,7 +88,7 @@ class Exceptions:
 
 class MediaTailorClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html)
     """
 
@@ -102,7 +104,7 @@ class MediaTailorClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#can_paginate)
         """
 
@@ -111,13 +113,14 @@ class MediaTailorClient(BaseClient):
         *,
         ChannelName: str,
         Outputs: List["RequestOutputItemTypeDef"],
-        PlaybackMode: Literal["LOOP"],
+        PlaybackMode: PlaybackModeType,
+        FillerSlate: "SlateSourceTypeDef" = None,
         Tags: Dict[str, str] = None
     ) -> CreateChannelResponseTypeDef:
         """
         Creates a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_channel)
         """
 
@@ -134,7 +137,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates a program.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.create_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.create_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_program)
         """
 
@@ -150,7 +153,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_source_location)
         """
 
@@ -165,7 +168,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates name for a specific VOD source in a source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_vod_source)
         """
 
@@ -173,7 +176,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel)
         """
 
@@ -181,7 +184,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a channel's IAM policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel_policy)
         """
 
@@ -189,7 +192,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes the playback configuration for the specified name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_playback_configuration)
         """
 
@@ -197,7 +200,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a specific program on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_program)
         """
 
@@ -205,7 +208,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_source_location)
         """
 
@@ -213,7 +216,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_vod_source)
         """
 
@@ -221,7 +224,7 @@ class MediaTailorClient(BaseClient):
         """
         Describes the properties of a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_channel)
         """
 
@@ -231,7 +234,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves the properties of the requested program.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_program)
         """
 
@@ -241,7 +244,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves the properties of the requested source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_source_location)
         """
 
@@ -251,7 +254,7 @@ class MediaTailorClient(BaseClient):
         """
         Provides details about a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_vod_source)
         """
 
@@ -265,7 +268,7 @@ class MediaTailorClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#generate_presigned_url)
         """
 
@@ -273,7 +276,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves information about a channel's IAM policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_policy)
         """
 
@@ -288,7 +291,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves information about your channel's schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_schedule)
         """
 
@@ -296,7 +299,7 @@ class MediaTailorClient(BaseClient):
         """
         Returns the playback configuration for the specified name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_playback_configuration)
         """
 
@@ -306,7 +309,7 @@ class MediaTailorClient(BaseClient):
         """
         Returns a list of alerts for the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.list_alerts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.list_alerts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_alerts)
         """
 
@@ -316,7 +319,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves a list of channels that are associated with this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_channels)
         """
 
@@ -327,7 +330,7 @@ class MediaTailorClient(BaseClient):
         Returns a list of the playback configurations defined in AWS Elemental
         MediaTailor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_playback_configurations)
         """
 
@@ -337,7 +340,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves a list of source locations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_source_locations)
         """
 
@@ -346,7 +349,7 @@ class MediaTailorClient(BaseClient):
         Returns a list of the tags assigned to the specified playback configuration
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_tags_for_resource)
         """
 
@@ -356,7 +359,7 @@ class MediaTailorClient(BaseClient):
         """
         Lists all the VOD sources in a source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_vod_sources)
         """
 
@@ -364,7 +367,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates an IAM policy for the channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_channel_policy)
         """
 
@@ -389,7 +392,7 @@ class MediaTailorClient(BaseClient):
         """
         Adds a new playback configuration to AWS Elemental MediaTailor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_playback_configuration)
         """
 
@@ -397,7 +400,7 @@ class MediaTailorClient(BaseClient):
         """
         Starts a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#start_channel)
         """
 
@@ -405,7 +408,7 @@ class MediaTailorClient(BaseClient):
         """
         Stops a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#stop_channel)
         """
 
@@ -413,7 +416,7 @@ class MediaTailorClient(BaseClient):
         """
         Adds tags to the specified playback configuration resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#tag_resource)
         """
 
@@ -421,7 +424,7 @@ class MediaTailorClient(BaseClient):
         """
         Removes tags from the specified playback configuration resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#untag_resource)
         """
 
@@ -431,7 +434,7 @@ class MediaTailorClient(BaseClient):
         """
         Updates an existing channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_channel)
         """
 
@@ -446,7 +449,7 @@ class MediaTailorClient(BaseClient):
         """
         Updates a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_source_location)
         """
 
@@ -460,7 +463,7 @@ class MediaTailorClient(BaseClient):
         """
         Updates a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_vod_source)
         """
 
@@ -469,21 +472,21 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["get_channel_schedule"]
     ) -> GetChannelSchedulePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_alerts"]) -> ListAlertsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listalertspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
         """
 
@@ -492,7 +495,7 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
         """
 
@@ -501,13 +504,13 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["list_source_locations"]
     ) -> ListSourceLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_vod_sources"]) -> ListVodSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.32/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
         """
