@@ -20,7 +20,9 @@ from .literals import (
     ChannelStateType,
     ModeType,
     OriginManifestTypeType,
+    PlaybackModeType,
     RelativePositionType,
+    ScheduleEntryTypeType,
     TypeType,
 )
 
@@ -202,6 +204,7 @@ _OptionalChannelTypeDef = TypedDict(
     "_OptionalChannelTypeDef",
     {
         "CreationTime": datetime,
+        "FillerSlate": "SlateSourceTypeDef",
         "LastModifiedTime": datetime,
         "Tags": Dict[str, str],
     },
@@ -218,12 +221,13 @@ _RequiredCreateChannelRequestRequestTypeDef = TypedDict(
     {
         "ChannelName": str,
         "Outputs": List["RequestOutputItemTypeDef"],
-        "PlaybackMode": Literal["LOOP"],
+        "PlaybackMode": PlaybackModeType,
     },
 )
 _OptionalCreateChannelRequestRequestTypeDef = TypedDict(
     "_OptionalCreateChannelRequestRequestTypeDef",
     {
+        "FillerSlate": "SlateSourceTypeDef",
         "Tags": Dict[str, str],
     },
     total=False,
@@ -243,6 +247,7 @@ CreateChannelResponseTypeDef = TypedDict(
         "ChannelName": str,
         "ChannelState": ChannelStateType,
         "CreationTime": datetime,
+        "FillerSlate": "SlateSourceTypeDef",
         "LastModifiedTime": datetime,
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
@@ -284,6 +289,7 @@ CreateProgramResponseTypeDef = TypedDict(
         "ChannelName": str,
         "CreationTime": datetime,
         "ProgramName": str,
+        "ScheduledStartTime": datetime,
         "SourceLocationName": str,
         "VodSourceName": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -463,6 +469,7 @@ DescribeChannelResponseTypeDef = TypedDict(
         "ChannelName": str,
         "ChannelState": ChannelStateType,
         "CreationTime": datetime,
+        "FillerSlate": "SlateSourceTypeDef",
         "LastModifiedTime": datetime,
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
@@ -487,6 +494,7 @@ DescribeProgramResponseTypeDef = TypedDict(
         "ChannelName": str,
         "CreationTime": datetime,
         "ProgramName": str,
+        "ScheduledStartTime": datetime,
         "SourceLocationName": str,
         "VodSourceName": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -978,6 +986,7 @@ _OptionalScheduleEntryTypeDef = TypedDict(
         "ApproximateDurationSeconds": int,
         "ApproximateStartTime": datetime,
         "ScheduleAdBreaks": List["ScheduleAdBreakTypeDef"],
+        "ScheduleEntryType": ScheduleEntryTypeType,
     },
     total=False,
 )
@@ -1075,6 +1084,7 @@ _OptionalTransitionTypeDef = TypedDict(
     "_OptionalTransitionTypeDef",
     {
         "RelativeProgram": str,
+        "ScheduledStartTimeMillis": int,
     },
     total=False,
 )
@@ -1107,6 +1117,7 @@ UpdateChannelResponseTypeDef = TypedDict(
         "ChannelName": str,
         "ChannelState": ChannelStateType,
         "CreationTime": datetime,
+        "FillerSlate": "SlateSourceTypeDef",
         "LastModifiedTime": datetime,
         "Outputs": List["ResponseOutputItemTypeDef"],
         "PlaybackMode": str,
